==> apimodule-1.0.5.tar.gz: lib/msimpersaa/response/sip_response.dart <==
class SipResponse {
  bool con;
  String msg;
  List<SipResults> results;

  SipResponse({this.con, this.msg, this.results});

  SipResponse.fromJson(Map<String, dynamic> json) {
    con = json['con'];
    msg = json['msg'];
    if (json['results'] != null) {
      results = <SipResults>[];
      json['results'].forEach((v) {
        results.add(SipResults.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['con'] = this.con;
    data['msg'] = this.msg;
    if (this.results != null) {
      data['results'] = this.results.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class SipResults {
  int id;
  String nomorSipp;
  String nomorStrp;
  String tanggalTerbit;
  String tanggalBerlaku;
  String documen;
  String pathFile;

  SipResults(
      {this.id,
      this.nomorSipp,
      this.nomorStrp,
      this.tanggalTerbit,
      this.tanggalBerlaku,
      this.documen,
      this.pathFile});

  SipResults.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    nomorSipp = json['nomor_sipp'];
    nomorStrp = json['nomor_strp'];
    tanggalTerbit = json['tanggal_terbit'];
    tanggalBerlaku = json['tanggal_berlaku'];
    documen = json['dokumen'];
    pathFile = json['path_file'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['id'] = this.id;
    data['nomor_sipp'] = this.nomorSipp;
    data['nomor_strp'] = this.nomorStrp;
    data['tanggal_terbit'] = this.tanggalTerbit;
    data['tanggal_berlaku'] = this.tanggalBerlaku;
    data['dokumen'] = this.documen;
    data['path_file'] = this.pathFile;
    return data;
  }
}

==> apimodule-1.0.6.tar.gz: lib/msimpersaa/response/sip_response.dart <==
class SipResponse {
  bool con;
  String msg;
  List<SipResults> results;

  SipResponse({this.con, this.msg, this.results});

  SipResponse.fromJson(Map<String, dynamic> json) {
    con = json['con'];
    msg = json['msg'];
    if (json['results'] != null) {
      results = <SipResults>[];
      json['results'].forEach((v) {
        results.add(SipResults.fromJson(v));
      });
    }
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['con'] = this.con;
    data['msg'] = this.msg;
    if (this.results != null) {
      data['results'] = this.results.map((v) => v.toJson()).toList();
    }
    return data;
  }
}

class SipResults {
  int id;
  String nomorSipp;
  String nomorStrp;
  String tanggalTerbit;
  String tanggalBerlaku;
  String document;
  String pathFile;

  SipResults(
      {this.id,
      this.nomorSipp,
      this.nomorStrp,
      this.tanggalTerbit,
      this.tanggalBerlaku,
      this.document,
      this.pathFile});

  SipResults.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    nomorSipp = json['nomor_sipp'];
    nomorStrp = json['nomor_strp'];
    tanggalTerbit = json['tanggal_terbit'];
    tanggalBerlaku = json['tanggal_berlaku'];
    document = json['dokumen'];
    pathFile = json['path_file'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = Map<String, dynamic>();
    data['id'] = this.id;
    data['nomor_sipp'] = this.nomorSipp;
    data['nomor_strp'] = this.nomorStrp;
    data['tanggal_terbit'] = this.tanggalTerbit;
    data['tanggal_berlaku'] = this.tanggalBerlaku;
    data['dokumen'] = this.document;
    data['path_file'] = this.pathFile;
    return data;
  }
}
